pub struct Stream<IO, Role, Guard = Direct> { /* private fields */ }Expand description
Websocket stream.
Depending on IO, Stream implements std::io::Read and std::io::Write
or tokio::io::AsyncRead and tokio::io::AsyncWrite.
Role decides whether to mask payload data.
It is reserved to provide extra infomation to apply optimizations.
See also: Stream::read, Stream::write.
Implementations
Sourceimpl<IO, Role, Guard> Stream<IO, Role, Guard>where
Role: RoleHelper,
impl<IO, Role, Guard> Stream<IO, Role, Guard>where
Role: RoleHelper,
Sourceimpl<IO, Role, Guard> Stream<IO, Role, Guard>
Check status.
impl<IO, Role, Guard> Stream<IO, Role, Guard>
Check status.
Sourcepub const fn is_ping_completed(&self) -> bool
pub const fn is_ping_completed(&self) -> bool
Check if a Ping frame is completely read.
Sourcepub const fn is_read_eof(&self) -> bool
pub const fn is_read_eof(&self) -> bool
Check if EOF is reached.
Sourcepub const fn is_read_close(&self) -> bool
pub const fn is_read_close(&self) -> bool
Check if a Close frame is received.
Sourcepub const fn is_read_end(&self) -> bool
pub const fn is_read_end(&self) -> bool
Check if a Close frame is received or EOF is reached.
Sourcepub const fn is_write_zero(&self) -> bool
pub const fn is_write_zero(&self) -> bool
Check if a WriteZero error occurred.
Sourcepub const fn is_read_partial_head(&self) -> bool
pub const fn is_read_partial_head(&self) -> bool
Check if a frame head is partially read.
Sourcepub const fn is_write_partial_head(&self) -> bool
pub const fn is_write_partial_head(&self) -> bool
Check if frame head is partially written.
Sourceimpl<Role: RoleHelper> Stream<TcpStream, Role>
impl<Role: RoleHelper> Stream<TcpStream, Role>